#!/bin/bash

: '
Copyright (C) 2022 Job Bautista

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
'

source libsox.sh

declare textintro='
  ___       ___     __        __   __    ___
   |  |__| |__     |__)  /\  |__) |__) |  |
   |  |  | |___    |  \ /~~\ |__) |__) |  |

           __                     __   ___  __
|__|  /\  /__`    |     /\  |\ | |  \ |__  |  \
|  | /~~\ .__/    |___ /~~\ | \| |__/ |___ |__/

The Rabbit Has Landed
Composed by ZUN for Touhou Kanjuden: Legacy of Lunatic Kingdom
Arranged by Job Bautista

'

enable3456Harmony

setTempo 155

setDefaultSynthType square # sine synth struggles with 6 channels

# intro
function ee_4h {
 declare -n note1=$1
 declare -n note2=$2
 declare -n note3=$3
 for i in 1 2
 do
  notes+=( "$ei:${note1[$4]},${note2[$5]}*${note3[$6]}_${note1[$7]}" )
 done
}
ee_4h b fs d 3 3 3 2; notes+=( "$qu:${b[4]},${fs[4]}*${d[4]}" );
ee_4h a fs d 3 3 3 2; notes+=( "$qu:${a[4]},${fs[4]}*${d[4]}" );
notes+=(
 "$dei:${gs[4]},${e[4]}"
 "$dei:${a[4]},${e[4]}"
 "$ei:${gs[4]},${e[4]}"
 "$ha:${fs[4]},${cs[4]}"
)
ee_4h b fs d 3 3 3 2
notes+=(
 "$ei:${fs[4]},${cs[4]}"
 "$ei:${a[4]},${e[4]}"
 "$ei:${b[4]},${fs[4]}"
 "$ei:${cs[5]},${fs[4]}"
 "$qu:${a[4]},${fs[4]}"
 "$dei:${gs[4]},${e[4]}"
 "$dei:${a[4]},${fs[4]}"
 "$ei:${b[4]},${gs[4]}"
 "$ha:${cs[5]},${as[4]}*${fs[4]}"
)
ee_4h e b g 4 3 3 3; notes+=( "$qu:${e[5]},${b[4]}*${g[4]}" );
ee_4h d b g 4 3 3 3; notes+=( "$qu:${d[5]},${b[4]}*${g[4]}" );
notes+=(
 "$dei:${cs[5]},${a[4]}"
 "$dei:${d[5]},${a[4]}"
 "$ei:${cs[5]},${a[4]}"
 "$ha:${b[4]},${fs[4]}"
)
ee_4h e b g 4 3 3 3
notes+=(
 "$ei:${b[4]},${fs[4]}"
 "$ei:${d[5]},${a[4]}"
 "$ei:${e[5]},${b[4]}"
 "$ei:${fs[5]},${b[4]}"
 "$qu:${d[5]},${b[4]}"
 "$dei:${cs[5]},${a[4]}"
 "$dei:${d[5]},${b[4]}"
 "$ei:${e[5]},${cs[5]}"
 "$ha:${fs[5]},${ds[5]}*${b[4]}"
)

# verse 1
notes+=(
 "$ei:${a[4]},${a[3]}"
 "$ei:${e[5]}"
 "$ei:${fs[5]},${a[3]}"
 "$si:${a[4]},${fs[4]}*${d[4]}"
 "$si:${cs[5]}"
 "$ei:${fs[5]},${a[3]}"
 "$ei:${gs[5]}"
 "$ei:${b[4]},${a[3]}"
 "$ei:${gs[5]}"
 "$ha:${a[5]},${e[5]}"

 "$dsi:${b[3]}"
 "$tsi:${g[5]}"
 "$ei:${gs[5]}"
 "$ei:${e[5]}"
 "$ei:${b[4]}"

 "$ei:${gs[4]},${gs[3]}"
 "$ei:${cs[5]}"
 "$ei:${e[5]},${gs[3]}"
 "$si:${b[4]},${e[4]}*${cs[4]}"
 "$si:${cs[5]}"
 "$ei:${f[5]},${gs[3]}"
 "$ei:${b[5]}"
 "$ei:${f[5]}"
 "$ei:${gs[5]}"
 "$dqu:${a[5]}"
 "$dqu:${gs[5]}"
 "$qu:${e[5]}"

 "$ei:${a[4]},${fs[3]}"
 "$ei:${e[5]}"
 "$ei:${fs[5]},${fs[3]}"
 "$si:${a[4]},${d[4]}*${a[3]}"
 "$si:${e[5]}"
 "$ei:${fs[5]},${fs[3]}"
 "$ei:${gs[5]}"
 "$ei:${b[4]},${fs[3]}"
 "$ei:${fs[5]}"
 "$dei:${gs[5]}"
 "$dei:${a[5]}"
 "$ei:${b[5]}"

 "$dsi:${gs[3]}"
 "$tsi:${g[5]}"
 "$ei:${gs[5]}"
 "$ei:${fs[5]},${gs[3]}"
 "$ei:${gs[5]}"
 "$ei:${f[5]},${gs[3]}"
 "$ei:${gs[5]}"
 "$ei:${cs[6]},${gs[3]}"
 "$ei:${f[5]}"
 "$ei:${gs[5]},${gs[3]}"
 "$ei:${cs[6]}"
 "$ei:${f[5]},${gs[3]}"
 "$ei:${gs[5]}"
 "$dqu:${b[5]}"
 ".967:${a[5]}" # half + eighth note
)

# verse 2
notes+=(
 "$ei:${a[4]},${fs[4]}"
 "$ei:${e[5]},${a[4]}"
 "$ei:${fs[5]},${d[5]}"
 "$si:${a[4]},${d[3]}"
 "$si:${cs[5]}"
 "$ei:${fs[5]},${cs[5]}"
 "$ei:${gs[5]},${e[5]}"
 "$ei:${b[4]},${fs[4]}"
 "$ei:${gs[5]},${e[5]}"
 "$ha:${a[5]},${e[5]}*${b[4]}"

 "$si:${cs[4]}"
 "$tsi:${b[3]}"
 "$tsi:${g[5]}"
 "$ei:${gs[5]},${e[5]}"
 "$ei:${e[5]},${b[4]}"
 "$ei:${b[4]},${gs[4]}"
 "$ei:${gs[4]}"
 "$ei:${cs[5]},${gs[4]}"
 "$ei:${e[5]},${cs[5]}"
 "$si:${b[4]},${gs[3]}"
 "$si:${cs[5]},${cs[4]}"
 "$ei:${f[5]},${cs[5]}"
 "$ei:${b[5]},${f[5]}"
 "$ei:${f[5]},${cs[5]}"
 "$ei:${gs[5]},${f[5]}"
 "$dqu:${a[5]},${fs[5]}"
 "$dqu:${gs[5]},${e[5]}"
 "$qu:${e[5]},${b[4]}"

 "$ei:${a[4]},${fs[4]}"
 "$ei:${e[5]},${cs[5]}"
 "$ei:${fs[5]},${d[5]}"
 "$si:${a[4]},${fs[3]}"
 "$si:${e[5]},${a[3]}"
 "$ei:${fs[5]},${d[5]}"
 "$ei:${gs[5]},${e[5]}"
 "$ei:${b[4]},${gs[4]}"
 "$ei:${fs[5]},${d[5]}"
 "$dei:${gs[5]},${e[5]}"
 "$dei:${a[5]},${fs[5]}"
 "$ei:${b[5]},${gs[5]}"

 "$dsi:${gs[3]}"
 "$tsi:${g[5]}"
 "$ei:${gs[5]},${e[5]}"
 "$ei:${fs[5]},${cs[5]}"
 "$ei:${gs[5]},${e[5]}"
 "$ei:${f[5]},${cs[5]}"
 "$ei:${gs[5]},${f[5]}"
 "$ei:${cs[6]},${gs[5]}"
 "$ei:${f[5]},${cs[5]}"
 "$ei:${gs[5]},${f[5]}"
 "$ei:${cs[6]},${gs[5]}"
 "$ei:${f[5]},${cs[5]}"
 "$ei:${gs[5]},${f[5]}"
 "$dqu:${b[5]},${gs[5]}"
 ".967:${a[5]},${fs[5]}"
)

# verse 3
notes+=(
 "$qu:${g[4]},${ds[4]}*${as[3]}_${g[3]}"
 "$ei:${d[5]},${g[4]}*${ds[4]}"
 "$ei:${d[5]},${as[3]}"
 "$ei:${c[5]},${f[3]}"
 "$ei:${c[5]},${c[4]}*${a[3]}"
 "$ei:${c[5]}"
 "$ei:${c[5]}"
)
function verse3-common1 {
 notes+=(
  "$dei:${g[4]},${d[4]}*${as[3]}_${g[3]}@${d[3]}"
  "$dei:${c[5]}"
  "$ei:${d[5]}"
  "$dei:${f[5]}"
  "$dei:${d[5]}"
  "$ei:${c[5]}"

  "$qu:${g[4]}"
  "$qu:${d[5]}"
  "$ei:${c[5]},${f[3]}"
  "$ei:${c[5]},${c[3]}"
  "$ei:${c[5]},${a[3]}*${f[3]}"
  "$ei:${c[5]},${a[3]}*${f[3]}"
 )
}
verse3-common1
notes+=(
 "$dei:${g[4]}"
 "$dei:${c[5]}"
 "$ei:${d[5]},${g[3]}"
 "$si:${g[5]},${as[3]}*${g[3]}"
 "$si:${f[5]},${d[4]}"
 "$si:${g[5]},${g[3]}"
 "$si:${f[5]}"
 "$ei:${d[5]},${d[4]}*${as[3]}_${g[3]}"
 "$ei:${as[4]},${g[3]}*${d[3]}"

 "$qu:${g[4]}"
 "$ei:${d[5]},${g[4]}*${ds[4]}"
 "$ei:${d[5]},${as[3]}"
 "$ei:${c[5]},${f[3]}"
 "$ei:${c[5]},${c[4]}*${a[3]}"
 "$ei:${c[5]}"
 "$ei:${c[5]}"
)
verse3-common1
notes+=(
 "$dei:${g[4]}"
 "$dei:${c[5]}"
 "$ei:${d[5]},${g[3]}"
 "$dei:${g[5]}"
 "$dei:${g[6]}"
 "$ei:${d[6]},${d[4]}*${as[3]}_${g[3]}"
)
function verse3-common2 {
 notes+=(
  "$qu:${g[4]},${ds[4]}"
  "$ei:${d[5]},${as[4]}*${ds[3]}"
  "$ei:${d[5]},${as[4]}"
  "$ei:${c[5]},${a[4]}*${f[3]}"
  "$ei:${c[5]},${a[4]}"
  "$ei:${c[5]},${a[4]}*${f[3]}"
  "$ei:${c[5]},${a[4]}"

  "$dei:${g[4]},${d[4]}"
  "$dei:${c[5]},${g[4]}"
  "$ei:${d[5]},${as[4]}"
  "$dei:${f[5]},${d[5]}"
  "$dei:${d[5]},${as[4]}"
  "$ei:${c[5]},${g[4]}"

  "$qu:${g[4]},${ds[4]}"
  "$qu:${d[5]},${as[4]}"
  "$ei:${c[5]},${a[4]}*${f[3]}"
  "$ei:${c[5]},${a[4]}"
  "$ei:${c[5]},${a[4]}*${f[3]}"
  "$ei:${c[5]},${a[4]}"
 )
}
verse3-common2
notes+=(
 "$dei:${g[4]},${d[4]}"
 "$dei:${c[5]},${g[4]}"
 "$ei:${d[5]},${as[4]}"
 "$si:${g[5]},${d[5]}"
 "$si:${f[5]}"
 "$si:${g[5]},${d[5]}*${as[3]}_${g[3]}"
 "$si:${f[5]}"
 "$ei:${d[5]},${as[4]}"
 "$ei:${as[4]},${g[4]}"
)
verse3-common2
notes+=(
 "$dei:${g[4]}"
 "$dei:${c[5]}"
 "$ei:${d[5]}"
 "$dei:${g[5]}"
 "$dei:${g[6]}"
 "$ei:${d[6]}"
)

# verse 4
notes+=(
 "$ei:${fs[4]},${fs[3]}"
 "$ei:${cs[5]}"
 "$ei:${ds[5]},${fs[3]}"
 "$si:${fs[4]},${ds[4]}*${b[3]}"
 "$si:${as[4]}"
 "$ei:${ds[5]},${fs[3]}"
 "$ei:${f[5]}"
 "$ei:${gs[4]},${fs[3]}"
 "$ei:${f[5]}"
 "$ha:${fs[5]},${cs[5]}"

 "$dsi:${gs[3]}"
 "$tsi:${e[5]}"
 "$ei:${f[5]}"
 "$ei:${cs[5]}"
 "$ei:${gs[4]}"

 "$ei:${f[4]},${f[3]}"
 "$ei:${as[4]}"
 "$ei:${cs[5]},${f[3]}"
 "$si:${gs[4]},${cs[4]}*${as[3]}"
 "$si:${as[4]}"
 "$ei:${d[5]},${f[3]}"
 "$ei:${gs[5]}"
 "$ei:${d[5]}"
 "$ei:${f[5]}"
 "$dqu:${fs[5]}"
 "$dqu:${f[5]}"
 "$qu:${cs[5]}"

 "$ei:${fs[4]},${ds[3]}"
 "$ei:${cs[5]}"
 "$ei:${ds[5]},${ds[3]}"
 "$si:${fs[4]},${b[3]}*${fs[3]}"
 "$si:${cs[5]}"
 "$ei:${ds[5]},${ds[3]}"
 "$ei:${f[5]}"
 "$ei:${gs[4]},${ds[3]}"
 "$ei:${ds[5]}"
 "$dei:${f[5]}"
 "$dei:${fs[5]}"
 "$ei:${gs[5]}"

 "$dsi:${f[3]}"
 "$tsi:${e[5]}"
 "$ei:${f[5]}"
 "$ei:${ds[5]}"
 "$ei:${f[5]}"

 "$ei:${d[5]},${f[3]}"
 "$ei:${f[5]}"
 "$ei:${as[5]},${f[3]}"
 "$ei:${d[5]}"
 "$ei:${f[5]},${f[3]}"
 "$ei:${as[5]}"
 "$ei:${d[5]},${f[3]}"
 "$ei:${f[5]}"
 "$dqu:${gs[5]}"
 ".967:${fs[5]}"

 "$ei:${fs[4]},${ds[4]}"
 "$ei:${cs[5]},${fs[4]}"
 "$ei:${ds[5]},${b[4]}"
 "$si:${fs[4]},${b[3]}"
 "$si:${as[4]},${ds[3]}"
 "$ei:${ds[5]},${as[4]}"
 "$ei:${f[5]},${cs[5]}"
 "$ei:${gs[4]},${ds[4]}"
 "$ei:${f[5]},${cs[5]}"
 "$ha:${fs[5]},${cs[5]}*${gs[4]}"

 "$si:${as[3]}"
 "$tsi:${cs[3]}"
 "$tsi:${e[5]}"
 "$ei:${f[5]},${cs[5]}"
 "$ei:${cs[5]},${gs[4]}"
 "$ei:${gs[4]},${f[4]}"

 "$ei:${f[4]}"
 "$ei:${as[4]},${f[4]}"
 "$ei:${cs[5]},${as[4]}"
 "$si:${gs[4]},${f[3]}"
 "$si:${as[4]},${as[3]}"
 "$ei:${d[5]},${as[4]}"
 "$ei:${gs[5]},${d[5]}"
 "$ei:${d[5]},${as[4]}"
 "$ei:${f[5]},${d[5]}"
 "$dqu:${fs[5]},${ds[5]}"
 "$dqu:${f[5]},${cs[5]}"
 "$qu:${cs[5]},${gs[4]}"

 "$ei:${fs[4]},${ds[4]}"
 "$ei:${cs[5]},${as[4]}"
 "$ei:${ds[5]},${b[4]}"
 "$si:${fs[4]},${ds[3]}"
 "$si:${cs[5]},${fs[3]}"
 "$ei:${ds[5]},${b[4]}"
 "$ei:${f[5]},${cs[5]}"
 "$ei:${gs[4]},${f[4]}"
 "$ei:${ds[5]},${b[4]}"
 "$dei:${f[5]},${cs[5]}"
 "$dei:${fs[5]},${ds[5]}"
 "$ei:${gs[5]},${f[5]}"

 "$si:${f[3]}"
 "$tsi:${gs[3]}"
 "$tsi:${e[5]}"
 "$ei:${f[5]},${cs[5]}"
 "$ei:${ds[5]},${as[4]}"
 "$ei:${f[5]},${cs[5]}"

 "$ei:${d[5]},${as[4]}"
 "$ei:${f[5]},${d[5]}"
 "$ei:${as[5]},${f[5]}"
 "$ei:${d[5]},${as[4]}"
 "$ei:${f[5]},${d[5]}"
 "$ei:${as[5]},${f[5]}"
 "$ei:${d[5]},${as[4]}"
 "$ei:${f[5]},${d[5]}"
 "$dqu:${gs[5]},${f[5]}"
 ".967:${fs[5]},${ds[5]}"
)

# verse 5
notes+=(
 "$qu:${e[4]},${c[4]}*${c[3]}"
 "$ei:${b[4]},${g[4]}"
 "$ei:${b[4]},${g[4]}"
 "$ei:${a[4]},${fs[4]}*${d[3]}"
 "$ei:${a[4]},${fs[4]}*${d[3]}"
 "$ei:${a[4]},${fs[4]}*${fs[3]}"
 "$ei:${a[4]},${fs[4]}*${d[3]}"

 "$dei:${e[4]},${b[3]}"
 "$dei:${a[4]},${e[4]}"
 "$ei:${b[4]},${g[4]}"
 "$dei:${b[6]},${b[5]}*${d[5]}_${b[4]}"
 "$dei:${b[4]},${g[4]}"
 "$ei:${a[4]},${e[4]}"

 "$qu:${e[4]},${c[4]}"
 "$qu:${b[4]},${g[4]}*${e[3]}_${c[3]}"
 "$ei:${a[6]},${a[5]}*${a[4]}_${fs[4]}@${d[4]}^${a[3]}"
 "$ei:${a[4]},${fs[4]}*${d[4]}_${a[3]}"
 "$ei:${d[6]},${a[4]}*${fs[4]}_${d[4]}@${a[3]}"
 "$ei:${a[4]},${fs[4]}*${d[4]}_${a[3]}"

 "$dei:${fs[6]},${fs[5]}*${e[4]}_${b[3]}"
 "$dei:${g[6]},${g[5]}*${a[4]}_${e[4]}"
 "$ei:${a[6]},${a[5]}*${b[4]}_${g[4]}"
 "$dei:${g[6]},${g[5]}"
 "$dei:${fs[6]},${fs[5]}"
 "$ei:${b[5]},${b[4]}*${g[4]}_${e[4]}"

 "$qu:${e[4]},${b[3]}"
 "$ei:${b[4]},${g[4]}"
 "$ei:${b[4]},${g[4]}"
 "$ei:${a[4]},${fs[4]}"
 "$ei:${a[4]},${fs[4]}"
 "$ei:${a[4]},${fs[4]}"
 "$ei:${a[4]},${fs[4]}"

 "$dei:${e[4]},${b[3]}"
 "$dei:${a[4]},${e[4]}"
 "$ei:${b[4]},${g[4]}*${g[3]}_${e[3]}"
 "$dei:${d[5]},${b[4]}"
 "$dei:${b[4]},${g[4]}*${g[3]}_${e[3]}"
 "$ei:${a[4]},${e[4]}*${g[3]}_${e[3]}"

 "$qu:${e[4]},${c[4]}*${e[3]}_${c[3]}@${g[2]}"
 "$qu:${b[6]},${b[5]}*${b[4]}_${g[4]}@${c[4]}"
 "$ei:${a[4]},${fs[4]}*${a[3]}"
 "$ei:${a[4]},${fs[4]}*${a[3]}"
 "$ei:${a[6]},${a[5]}*${a[4]}_${fs[4]}@${a[3]}"
 "$ei:${a[4]},${fs[4]}*${a[3]}"

 "$dei:${g[6]},${g[5]}*${b[4]}_${e[4]}"
 "$dei:${a[6]},${a[5]}*${e[5]}_${a[4]}"
 "$ei:${b[6]},${b[5]}*${g[5]}_${b[4]}"
 "$ei:${e[6]},${b[5]}*${e[5]}"
)
notes+=( "$si:${e[3]},${e[2]}" )
silence si
notes+=( "$si:${e[3]},${e[2]}" )
silence si
notes+=( "$si:${e[3]},${e[2]}" )
silence si

# verse 6 which is almost like intro
ee_4h b fs d 3 3 3 2; notes+=( "$qu:${b[4]},${fs[4]}*${d[4]}" );
ee_4h a fs d 3 3 3 2; notes+=( "$qu:${a[4]},${fs[4]}*${d[4]}" );
notes+=(
 "$dei:${gs[4]},${e[4]}"
 "$dei:${a[4]},${e[4]}"
 "$ei:${gs[4]},${e[4]}"
 "$ha:${fs[4]},${cs[4]}"
)
ee_4h b fs d 3 3 3 2
notes+=(
 "$ei:${fs[4]},${cs[4]}"
 "$ei:${a[4]},${e[4]}"
 "$ei:${b[4]},${fs[4]}*${a[3]}_${fs[3]}"
 "$ei:${cs[5]},${fs[4]}*${a[3]}_${fs[3]}"
 "$qu:${a[4]},${fs[4]}"
 "$dei:${gs[4]},${e[4]}"
 "$dei:${a[4]},${fs[4]}"
 "$ei:${b[4]},${gs[4]}"
 "$ha:${cs[5]},${as[4]}*${fs[4]}_${cs[4]}"
)
ee_4h e b g 4 3 3 3; notes+=( "$qu:${g[5]},${e[5]}*${b[4]}_${g[4]}" );
ee_4h d b g 4 3 3 3; notes+=( "$qu:${g[5]},${d[5]}*${b[4]}_${g[4]}" );
notes+=(
 "$dei:${cs[5]},${a[4]}"
 "$dei:${d[5]},${a[4]}"
 "$ei:${cs[5]},${a[4]}"
 "$ha:${b[4]},${fs[4]}"
)
ee_4h e b g 4 3 3 3
notes+=(
 "$ei:${e[5]},${b[4]}*${fs[4]}"
 "$ei:${e[5]},${d[4]}*${a[4]}"
 "$ei:${e[5]},${b[4]}*${d[4]}_${b[3]}@${g[3]}^${d[3]}"
 "$ei:${fs[5]},${b[4]}*${d[4]}_${b[3]}@${g[3]}^${d[3]}"
 "$qu:${d[5]},${b[4]}*${fs[4]}"
 "$dei:${cs[5]},${a[4]}*${e[4]}"
 "$dei:${d[5]},${b[4]}*${fs[4]}"
 "$ei:${e[5]},${cs[5]}*${a[4]}"
 "$ha:${fs[5]},${ds[5]}*${b[4]}_${fs[4]}"
)

# verse 7 which is almost like verse 1
notes+=(
 "$ei:${a[4]},${a[2]}"
 "$ei:${e[5]}"
 "$ei:${fs[5]},${a[2]}"
 "$si:${a[4]},${a[3]}*${fs[3]}_${d[4]}"
 "$si:${cs[5]}"
 "$ei:${fs[5]},${a[2]}"
 "$ei:${gs[5]}"
 "$ei:${b[4]},${a[2]}"
 "$ei:${gs[5]}"
 "$ha:${a[5]},${e[5]}"

 "$dsi:${b[2]}"
 "$tsi:${g[5]}"
 "$ei:${gs[5]}"
 "$ei:${e[5]}"
 "$ei:${b[4]}"

 "$ei:${gs[4]},${gs[2]}"
 "$ei:${cs[5]}"
 "$ei:${e[5]},${gs[2]}"
 "$si:${b[4]},${gs[3]}*${e[3]}_${cs[3]}"
 "$si:${cs[5]}"
 "$ei:${f[5]},${gs[2]}"
 "$ei:${b[5]}"
 "$ei:${f[5]}"
 "$ei:${gs[5]}"
 "$dqu:${a[5]}"
 "$dqu:${gs[5]}"
 "$qu:${e[5]}"

 "$ei:${a[4]},${fs[2]}"
 "$ei:${e[5]}"
 "$ei:${fs[5]},${fs[2]}"
 "$si:${a[4]},${fs[3]}*${d[3]}_${a[2]}"
 "$si:${e[5]}"
 "$ei:${fs[5]},${fs[2]}"
 "$ei:${gs[5]}"
 "$ei:${b[4]},${fs[2]}"
 "$ei:${fs[5]}"
 "$dei:${gs[5]}"
 "$dei:${a[5]}"
 "$ei:${b[5]}"

 "$dsi:${gs[2]}"
 "$tsi:${g[5]}"
 "$ei:${gs[5]}"
 "$ei:${fs[5]},${gs[2]}"
 "$ei:${gs[5]}"
 "$ei:${f[5]},${gs[2]}"
 "$ei:${gs[5]}"
 "$ei:${cs[6]},${gs[2]}"
 "$ei:${f[5]}"
 "$ei:${gs[5]},${gs[2]}"
 "$ei:${cs[6]}"
 "$ei:${f[5]},${gs[2]}"
 "$ei:${gs[5]}"
 "$dqu:${b[5]}"
 ".967:${a[5]}"
)

# verse 8 which is almost like verse 2
notes+=(
 "$ei:${a[4]},${fs[4]}*${a[2]}"
 "$ei:${e[5]},${a[4]}"
 "$ei:${fs[5]},${d[5]}*${a[2]}"
 "$si:${a[4]},${a[3]}*${fs[3]}_${d[3]}"
 "$si:${cs[5]}"
 "$ei:${fs[5]},${cs[5]}*${a[2]}"
 "$ei:${gs[5]},${e[5]}"
 "$ei:${b[4]},${fs[4]}*${a[2]}"
 "$ei:${gs[5]},${e[5]}"
 "$ha:${a[5]},${e[5]}*${b[4]}"

 "$dsi:${b[2]}"
 "$tsi:${g[5]}"
 "$ei:${gs[5]},${e[5]}"
 "$ei:${e[5]},${b[4]}"
 "$ei:${b[4]},${gs[4]}"

 "$ei:${gs[4]},${gs[2]}"
 "$ei:${cs[5]},${gs[4]}"
 "$ei:${e[5]},${cs[5]}*${gs[2]}"
 "$si:${b[4]},${gs[3]}*${e[3]}_${cs[3]}"
 "$si:${cs[5]}"
 "$ei:${f[5]},${cs[5]}*${gs[2]}"
 "$ei:${b[5]},${f[5]}"
 "$ei:${f[5]},${cs[5]}"
 "$ei:${gs[5]},${f[5]}"
 "$dqu:${a[5]},${fs[5]}"
 "$dqu:${gs[5]},${e[5]}"
 "$qu:${e[5]},${b[4]}"

 "$ei:${a[4]},${fs[4]}*${fs[2]}"
 "$ei:${e[5]},${cs[5]}"
 "$ei:${fs[5]},${d[5]}*${fs[2]}"
 "$si:${a[4]},${fs[3]}*${d[3]}_${a[2]}"
 "$si:${e[5]}"
 "$ei:${fs[5]},${d[5]}*${fs[2]}"
 "$ei:${gs[5]},${e[5]}"
 "$ei:${b[4]},${gs[4]}*${fs[2]}"
 "$ei:${fs[5]},${d[5]}"
 "$dei:${gs[5]},${e[5]}"
 "$dei:${a[5]},${fs[5]}"
 "$ei:${b[5]},${gs[5]}"

 "$dsi:${gs[2]}"
 "$tsi:${g[5]}"
 "$ei:${gs[5]},${e[5]}"
 "$ei:${fs[5]},${cs[5]}*${gs[2]}"
 "$ei:${gs[5]},${e[5]}"
 "$ei:${f[5]},${cs[5]}*${gs[2]}"
 "$ei:${gs[5]},${f[5]}"
 "$ei:${cs[6]},${gs[5]}*${gs[2]}"
 "$ei:${f[5]},${cs[5]}"
 "$ei:${gs[5]},${f[5]}*${gs[2]}"
 "$ei:${cs[6]},${gs[5]}"
 "$ei:${f[5]},${cs[5]}*${gs[2]}"
 "$ei:${gs[5]},${f[5]}"
 "$dqu:${b[5]},${gs[5]}"
 ".967:${a[5]},${fs[5]}"
)

# verse 9 which is a higher pitched verse 3
notes+=(
 "$qu:${g[5]},${ds[5]}*${ds[4]}_${as[4]}@${g[4]}"
 "$ei:${d[6]},${as[5]}*${g[4]}_${ds[4]}"
 "$ei:${d[6]},${as[5]}*${as[3]}"
 "$ei:${c[6]},${a[5]}*${f[3]}"
 "$ei:${c[6]},${a[5]}*${c[4]}_${a[3]}"
 "$ei:${c[6]},${a[5]}"
 "$ei:${c[6]},${a[5]}"
)
function verse9-common1 {
 notes+=(
  "$dei:${g[5]},${d[5]}"
  "$dei:${c[6]},${g[5]}"
  "$ei:${d[6]},${as[5]}"
  "$dei:${f[6]},${d[6]}"
  "$dei:${d[6]},${as[5]}"
  "$ei:${c[6]},${g[5]}"
 )
}
verse9-common1
notes+=(
 "$qu:${g[5]},${ds[5]}"
 "$qu:${d[6]},${as[5]}"
 "$ei:${c[6]},${a[5]}*${f[5]}_${c[5]}@${f[3]}"
 "$ei:${c[6]},${a[5]}*${f[5]}_${c[5]}@${c[3]}"
 "$ei:${c[6]},${a[5]}*${f[5]}_${c[5]}@${a[3]}^${f[3]}"
 "$ei:${c[6]},${a[5]}*${f[5]}_${c[5]}@${a[3]}^${f[3]}"

 "$dei:${g[5]},${d[5]}"
 "$dei:${c[6]},${g[5]}"
 "$ei:${d[6]},${as[5]}*${g[3]}"
 "$si:${g[6]},${d[6]}*${as[3]}"
 "$si:${f[6]},${d[4]}"
 "$si:${g[6]},${d[6]}"
 "$si:${f[6]}"
 "$ei:${d[6]},${as[5]}*${d[4]}_${as[3]}@${g[3]}"
 "$ei:${as[5]},${g[5]}*${g[3]}_${d[3]}"

 "$qu:${g[5]},${d[5]}"
 "$ei:${d[6]},${as[5]}*${g[4]}_${ds[4]}"
 "$ei:${d[6]},${as[5]}*${as[3]}"
 "$ei:${c[6]},${a[5]}*${f[3]}"
 "$ei:${c[6]},${a[5]}*${c[4]}_${a[3]}"
 "$ei:${c[6]},${a[5]}"
 "$ei:${c[6]},${a[5]}"
)
verse9-common1
notes+=(
 "$qu:${g[5]},${ds[5]}*${g[4]}"
 "$qu:${d[6]},${as[5]}*${ds[5]}"
 "$ei:${c[6]},${a[5]}*${c[5]}_${f[3]}"
 "$ei:${c[6]},${a[5]}*${c[5]}_${c[3]}"
 "$ei:${c[6]},${a[5]}*${c[5]}_${a[3]}@${f[3]}"
 "$ei:${c[6]},${a[5]}*${c[5]}_${a[3]}@${f[3]}"

 "$dei:${d[6]},${g[6]}"
 "$dei:${g[6]},${c[6]}"
 "$ei:${as[6]},${d[6]}*${g[3]}"
 "$ha:${g[6]},${d[6]}"

 "$qu:${g[4]},${ds[4]}*${ds[3]}"
 "$ei:${d[5]},${as[4]}"
 "$ei:${d[5]},${as[4]}"
 "$ei:${c[5]},${a[4]}*${f[3]}"
 "$ei:${c[5]},${a[4]}*${f[3]}"
 "$ei:${c[5]},${a[4]}*${a[3]}"
 "$ei:${c[5]},${a[4]}*${f[3]}"

 "$dei:${g[4]},${d[4]}"
 "$dei:${c[5]},${g[4]}"
 "$ei:${d[5]},${as[4]}"
 "$dei:${d[6]},${f[5]}*${d[5]}"
 "$dei:${d[5]},${as[4]}"
 "$ei:${c[5]},${g[4]}"

 "$qu:${g[4]},${ds[4]}"
 "$qu:${d[5]},${as[4]}*${g[3]}_${ds[3]}"
 "$ei:${c[6]},${c[5]}*${a[4]}_${f[4]}@${c[4]}"
 "$ei:${c[5]},${a[4]}*${f[4]}_${c[4]}"
 "$ei:${f[6]},${c[5]}*${a[4]}_${f[4]}@${c[4]}"
 "$ei:${c[5]},${a[4]}*${f[4]}_${c[4]}"

 "$dei:${a[6]},${a[5]}*${g[4]}_${d[4]}"
 "$dei:${as[6]},${as[5]}*${c[5]}_${g[4]}"
 "$ei:${c[6]},${d[5]}*${as[4]}"
 "$dei:${as[6]},${as[5]}"
 "$dei:${a[6]},${a[5]}"
 "$ei:${d[6]},${d[5]}"

 "$qu:${g[4]},${ds[4]}"
 "$ei:${d[5]},${as[4]}"
 "$ei:${d[5]},${as[4]}"
 "$ei:${c[5]},${a[4]}"
 "$ei:${c[5]},${a[4]}"
 "$ei:${c[5]},${a[4]}"
 "$ei:${c[5]},${a[4]}"

 "$dei:${g[4]},${d[4]}"
 "$dei:${c[5]},${g[4]}"
 "$ei:${d[5]},${as[4]}*${as[3]}_${g[3]}"
 "$dei:${f[5]},${d[5]}"
 "$dei:${d[5]},${as[4]}"
 "$ei:${c[5]},${g[4]}*${as[3]}_${g[3]}"

 "$qu:${g[4]},${ds[4]}*${g[3]}_${ds[3]}@${as[2]}"
 "$qu:${d[6]},${d[5]}*${as[4]}_${ds[4]}"
 "$ei:${c[5]},${a[4]}*${c[4]}"
 "$ei:${c[5]},${a[4]}*${c[4]}"
 "$ei:${c[6]},${c[5]}*${a[4]}_${c[4]}"
 "$ei:${c[5]},${a[4]}*${c[4]}"

 "$dei:${as[6]},${as[5]}*${d[5]}_${g[4]}"
 "$dei:${c[6]},${g[5]}*${c[5]}"
 "$ei:${d[6]},${as[5]}*${d[5]}"
 "$ei:${g[6]},${d[6]}*${g[5]}"
)
notes+=( "$si:${g[3]},${g[2]}" )
silence si
notes+=( "$si:${g[3]},${g[2]}" )
silence si
notes+=( "$si:${g[3]},${g[2]}" )
silence si

createSoxPipes
